@@ -10,22 +10,48 @@ __tests__ = (
 {
     "#url"     : "https://bato.to/title/86408-i-shall-master-this-family-official/1681030-ch_8",
     "#class"   : batoto.BatotoChapterExtractor,
+    "#pattern" : r"https://\w+\.mb\w\w\w\.org/media/7006/.+\.webp",
     "#count"   : 66,
 
-    "chapter"      : 8,
-    "chapter_id"   : 1681030,
-    "chapter_minor": "",
-    "chapter_url"  : "8",
-    "count"        : 66,
-    "date"         : "dt:2021-05-15 18:51:37",
-    "extension"    : "webp",
-    "filename"     : str,
-    "manga"        : "I Shall Master this Family! [Official]",
-    "manga_id"     : 86408,
-    "page"         : range(1, 66),
-    "title"        : "Observing",
-    "volume"       : 0,
-
+    "artist"        : ["Mon"],
+    "author"        : ["Kim Roah"],
+    "chapter"       : 8,
+    "chapter_id"    : 1681030,
+    "chapter_minor" : "",
+    "chapter_string": "Chapter 8",
+    "chapter_url"   : "8",
+    "count"         : 66,
+    "page"          : range(1, 66),
+    "cover"         : "https://n28.mbxma.org/thumb/ampi/c69/c69c33b47d05536b565df0ae2138ccd4c083bad2_400_600_52848.jpeg",
+    "date"          : "dt:2021-05-15 18:51:37",
+    "description"   : "The great Lombardi family was once at the top of the empire. After the death of its patriarch, the fate of the family and that of Firentia, born from a Lombardi and a peasant, fall to ruin at the hands of her useless and cruel cousins. But when she’s reincarnated as her seven-year-old self, she’ll work to protect the family’s honor, gain her grandpa Lulac’s favor, and prevent her own father’s death. In this lifetime, there’s only one way for her to win: become the head of their mighty household.",
+    "extension"     : "webp",
+    "filename"      : str,
+    "lang"          : "en",
+    "lang_orig"     : "ko",
+    "manga"         : "I Shall Master this Family! [Official]",
+    "manga_date"    : "dt:2021-05-10 20:18:58",
+    "manga_date_updated": "dt:2024-11-10 18:38:02",
+    "manga_id"      : 86408,
+    "manga_slug"    : "i-shall-master-this-family-official",
+    "published"     : "2021",
+    "score"         : range(8, 10),
+    "status"        : "ongoing",
+    "title"         : "Observing",
+    "uploader"      : "677083",
+    "volume"        : 0,
+    "genre"         : [
+        "drama",
+        "fantasy",
+        "full color",
+        "historical",
+        "manhwa",
+        "reincarnation",
+        "romance",
+        "shoujo",
+        "time travel",
+        "webtoon",
+    ],
 },
 
 {
@@ -100,14 +126,39 @@ __tests__ = (
 {
     "#url"     : "https://bato.to/title/113742-futsutsuka-na-akujo-de-wa-gozaimasu-ga-suuguu-chouso-torikae-den-official",
     "#class"   : batoto.BatotoMangaExtractor,
+    "#pattern" : batoto.BatotoChapterExtractor.pattern,
+    "#count"   : range(50, 80),
     "#options" : {"domain": "xbato.org"},
-    "#count"   : ">= 21",
 
+    "author"       : ["Satsuki Nakamura"],
+    "artist"       : ["Ei Ohitsuji", "Kana Yuki"],
     "chapter"      : int,
-    "chapter_minor": str,
+    "chapter_minor": {"", ".5", ".6", ".7", ".8", ".9"},
+    "cover"        : "https://n26.mbfpu.org/media/mbim/865/8652703e451b4ddefbd2eb2d270cbf6102430a40_600_843_155280.webp",
     "date"         : "type:datetime",
+    "description"  : "As the crown prince’s favored maiden at court, Kou Reirin’s future as the next empress is all but assured. That is, until her rival Shu Keigetsu, the court’s “sewer rat,” pushes her over a balcony! Reirin survives, but wakes up in Keigetsu’s body! Turns out, Keigetsu has used magic to swap bodies with Reirin in order to steal her position at court. After being sickly her whole life, Reirin is determined to use this new body to turn things around. She won’t let anything stop her, not even her impending execution!",
+    "lang"         : "en",
+    "lang_orig"    : "ja",
     "manga"        : "Futsutsuka na Akujo de wa Gozaimasu ga - Suuguu Chouso Torikae Den",
+    "manga_date"   : "dt:2022-11-07 09:10:20",
+    "manga_date_updated": "type:datetime",
     "manga_id"     : 113742,
+    "manga_slug"   : "futsutsuka-na-akujo-de-wa-gozaimasu-ga-suuguu-chouso-torikae-den",
+    "published"    : "2020",
+    "score"        : range(8, 10),
+    "status"       : "ongoing",
+    "uploader"     : "713741",
+    "genre"        : [
+        "adaptation",
+        "bodyswap",
+        "drama",
+        "fantasy",
+        "historical",
+        "josei",
+        "manga",
+        "romance",
+        "villainess",
+    ],
 },
 
 {
