@@ -469,6 +469,14 @@ __tests__ = (
     },
 },
 
+{
+    "#url"      : "https://civitai.com/user/jackietop515100/posts",
+    "#comment"  : "deleted user (#8299)",
+    "#class"    : civitai.CivitaiUserPostsExtractor,
+    "#options"  : {"timeout": 5, "retries": 2},
+    "#exception": exception.HttpError,
+},
+
 {
     "#url"  : "https://civitai.com/user/waomodder/images",
     "#class": civitai.CivitaiUserImagesExtractor,
