@@ -62,6 +62,42 @@ __tests__ = (
     ),
 },
 
+{
+    "#url"     : "https://fansly.com/post/831751284628414464",
+    "#comment" : "video - best format is non-manifest",
+    "#class"   : fansly.FanslyPostExtractor,
+    "#pattern" : r"https://cdn\d+.fansly.com/788576864472932352/831751193247105025.mp4\?.+",
+
+    "content"        : "off duty miyabi (⸝⸝> ω <⸝⸝)",
+    "date"           : "dt:2025-10-07 01:08:38",
+    "expiresAt"      : None,
+    "extension"      : "mp4",
+    "filename"       : "831751193247105025",
+    "id"             : "831751284628414464",
+    "file"           : {
+        "accountId"     : "788576864472932352",
+        "createdAt"     : 1759799297,
+        "date"          : "dt:2025-10-07 01:08:17",
+        "date_updated"  : "dt:2025-10-07 01:08:26",
+        "duration"      : 12.376667,
+        "flags"         : 6,
+        "format"        : 2,
+        "frameRate"     : 30.05,
+        "height"        : 590,
+        "id"            : "831751193247105025",
+        "location"      : "/788576864472932352/831751193247105025.mp4",
+        "mimetype"      : "video/mp4",
+        "originalHeight": 590,
+        "originalWidth" : 786,
+        "resolutionMode": 1,
+        "status"        : 1,
+        "type"          : "video",
+        "updatedAt"     : 1759799306,
+        "variantHash"   : {},
+        "width"         : 786,
+    },
+},
+
 {
     "#url"     : "https://fansly.com/Oliviaus/posts",
     "#class"   : fansly.FanslyCreatorPostsExtractor,
