@@ -41,6 +41,7 @@ __tests__ = (
         "catalog"  : "N/A",
         "count"    : 18,
         "date"     : "Dec 23rd, 2024",
+        "description": r"re:<p>Composer:.+",
         "developer": "",
         "name"     : "Last Kingdom (Goddess of Victory: NIKKE Original Soundtrack)",
         "platform" : ["Android", "iOS", "Windows"],
@@ -81,6 +82,7 @@ __tests__ = (
         "catalog"  : "PCCG-00357",
         "count"    : 36,
         "date"     : "Jul 1st, 2024",
+        "description": r"re:<p>Composer: Koji Kondo",
         "developer": "",
         "name"     : "Super Mario 64 Original Soundtrack",
         "platform" : ["N64"],
