@@ -183,6 +183,13 @@ __tests__ = (
     "#exception": exception.NotFoundError,
 },
 
+{
+    "#url"     : "https://www.pixiv.net/users/84930793/artworks",
+    "#comment" : "empty profile (#8066)",
+    "#class"   : pixiv.PixivArtworksExtractor,
+    "#count"   : 0,
+},
+
 {
     "#url"     : "https://www.pixiv.net/en/users/173530/avatar",
     "#class"   : pixiv.PixivAvatarExtractor,
