@@ -21,7 +21,7 @@ from datetime import datetime
 
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from gallery_dl import extractor, output, path, util, exception  # noqa E402
-from gallery_dl import postprocessor, config  # noqa E402
+from gallery_dl import postprocessor, config, archive  # noqa E402
 from gallery_dl.postprocessor.common import PostProcessor  # noqa E402
 
 
@@ -39,7 +39,7 @@ class FakeJob():
         self.get_logger = logging.getLogger
         self.hooks = collections.defaultdict(list)
 
-    def register_hooks(self, hooks, options):
+    def register_hooks(self, hooks, options=None):
         for hook, callback in hooks.items():
             self.hooks[hook].append(callback)
 
@@ -195,7 +195,8 @@ class ExecTest(BasePostprocessorTest):
 
     def test_command_string(self):
         self._create({
-            "command": "echo {} {_path} {_directory} {_filename} && rm {};",
+            "command": "echo {} {_path} {_temppath} {_directory} {_filename} "
+                       "&& rm {};",
         })
 
         with patch("gallery_dl.util.Popen") as p:
@@ -208,6 +209,7 @@ class ExecTest(BasePostprocessorTest):
             (f"echo "
              f"{self.pathfmt.realpath} "
              f"{self.pathfmt.realpath} "
+             f"{self.pathfmt.temppath} "
              f"{self.pathfmt.realdirectory} "
              f"{self.pathfmt.filename} "
              f"&& rm {self.pathfmt.realpath};"),
@@ -243,7 +245,8 @@ class ExecTest(BasePostprocessorTest):
     def test_command_many(self):
         self._create({
             "commands": [
-                "echo {} {_path} {_directory} {_filename} && rm {};",
+                "echo {} {_path} {_temppath} {_directory} {_filename} "
+                "&& rm {};",
                 ["~/script.sh", "{category}", "\fE _directory.upper()"],
             ]
         })
@@ -259,6 +262,7 @@ class ExecTest(BasePostprocessorTest):
                 (f"echo "
                  f"{self.pathfmt.realpath} "
                  f"{self.pathfmt.realpath} "
+                 f"{self.pathfmt.temppath} "
                  f"{self.pathfmt.realdirectory} "
                  f"{self.pathfmt.filename} "
                  f"&& rm {self.pathfmt.realpath};"),
@@ -353,6 +357,23 @@ class ExecTest(BasePostprocessorTest):
         )
         i.wait.assert_called_once_with()
 
+    def test_archive(self):
+        pp = self._create({
+            "command": ["echo", "foobar"],
+            "archive": ":memory:",
+            "event"  : "finalize",
+        })
+
+        self.assertIsInstance(pp.archive, archive.DownloadArchive)
+
+        with patch.object(pp.archive, "add") as m_aa, \
+                patch.object(pp.archive, "close") as m_ac:
+            self._trigger(("finalize",))
+        pp.archive.close()
+
+        m_aa.assert_called_once_with(self.pathfmt.kwdict)
+        m_ac.assert_called_once()
+
 
 class HashTest(BasePostprocessorTest):
 
@@ -811,6 +832,22 @@ class MetadataTest(BasePostprocessorTest):
 }
 """)
 
+    def test_archive(self):
+        pp = self._create({
+            "archive": ":memory:",
+            "event"  : "finalize",
+        })
+
+        self.assertIsInstance(pp.archive, archive.DownloadArchive)
+
+        with patch.object(pp.archive, "add") as m_aa, \
+                patch.object(pp.archive, "close") as m_ac:
+            self._trigger(("finalize",))
+        pp.archive.close()
+
+        m_aa.assert_called_once_with(self.pathfmt.kwdict)
+        m_ac.assert_called_once()
+
     def _output(self, mock):
         return "".join(
             call[1][0]
@@ -890,6 +927,23 @@ class PythonTest(BasePostprocessorTest):
         with self.assertRaises(exception.StopExtraction):
             self._trigger()
 
+    def test_archive(self):
+        pp = self._create({
+            "expression": "True",
+            "archive"   : ":memory:",
+            "event"     : "finalize",
+        })
+
+        self.assertIsInstance(pp.archive, archive.DownloadArchive)
+
+        with patch.object(pp.archive, "add") as m_aa, \
+                patch.object(pp.archive, "close") as m_ac:
+            self._trigger(("finalize",))
+        pp.archive.close()
+
+        m_aa.assert_called_once_with(self.pathfmt.kwdict)
+        m_ac.assert_called_once()
+
     def _write_module(self, path):
         with open(path, "w") as fp:
             fp.write("""
